# Unisender Go API

Библиотека Unisender Go API упрощает работу с веб-API [Unisender Go](https://go.unisender.ru/). Она предоставляет тонкую обёртку над библиотекой [HTTPX](https://www.python-httpx.org/): добавляет к обычным возможностям HTTPX свои схемы данных и удобные часто используемые функции, но не мешает, при необходимости, спускаться ниже на уровень HTTP-запросов.